'use client';
import Link from 'next/link';
import { useCallback, useEffect, useRef, useState } from 'react';
import BiPerson from '@/components/icons/BiPerson';

export default function Header(){
	const [is_visible, setVisibility] = useState(false);
	const [is_sidebar_open, setSidebar] = useState(false);
	const s = useRef(0);

	const onScroll = useCallback(function(){
		window.onscroll = function(){
			if(scrollY>200) setVisibility(s.current>scrollY);
			s.current=scrollY;
		}
	}, []);

	function onResize(){
		if(innerWidth>1279) setSidebar(false);
	}

	useEffect(() => {
		setVisibility(true);
		onResize();
		window.addEventListener("scroll", onScroll, { passive: true });
		window.addEventListener("resize", onResize);
		return () => {
			window.removeEventListener("scroll", onScroll);
			window.removeEventListener("resize", onResize);
		}
		// eslint-disable-next-line react-hooks/exhaustive-deps
	}, []);
	return <>
		<section className={`w-full max-w-[1274px] fixed left-1/2 -translate-x-1/2 mx-auto z-50 transition-[top] duration-500 ${is_visible ? 'top-2.5 xl:top-5' : '-top-20'} `}>
			<nav className={`flex items-center justify-between gap-x-4 shadow-[rgba(0,_0,_0,_0.1)_1px_1px_20px_1px] h-[72px] xl:h-[83px] mx-2 py-[0.781rem] px-4 xl:px-6 rounded-[25px] ${is_sidebar_open ? 'bg-transparent shadow-none' : 'bg-white'}`}>
				<div className="flex justify-center items-center">
					<Link href="/"><img src='https://ik.imagekit.io/choreless/v2/icons/choreless.svg' alt='Choreless' loading='lazy' className='h-[1.95rem] [@media(min-width:350px)]:h-9 [@media(min-width:450px)]:h-12 xl:h-[3.75rem]' /></Link>
					<p className="hidden xl:block p-2 ms-3 text-brand-black"><Link className="font-bold" href="tel:+1234567890">(888) 315-0445 </Link> | SEA & TACOM</p>
				</div>
				<div className='flex xl:hidden items-center [@media(min-width:500px)]:gap-x-2'>
					<Link href='/signup' className="xl:hidden btn btn-sm normal-case bg-blue-600 text-white hover:text-blue-600 hover:bg-transparent border !border-blue-600 rounded-[104px] h-10">Get Started</Link>
					<div className='btn btn-sm btn-ghost hover:bg-transparent fill-brand-black hover:fill-blue-700 w-fit [@media(min-width:500px)]:me-0' onClick={()=>{ setSidebar(!is_sidebar_open) }}>
						{
							is_sidebar_open ?
								<svg xmlns="http://www.w3.org/2000/svg" width="14" height="15" viewBox="0 0 15 15"><path fill="#ddd" fillRule="evenodd" d="M12.854 2.854a.5.5 0 0 0-.708-.708L7.5 6.793L2.854 2.146a.5.5 0 1 0-.708.708L6.793 7.5l-4.647 4.646a.5.5 0 0 0 .708.708L7.5 8.207l4.646 4.647a.5.5 0 0 0 .708-.708L8.207 7.5l4.647-4.646Z" clipRule="evenodd"/></svg>
							:
							<svg xmlns="http://www.w3.org/2000/svg" width="14" height="15" viewBox="0 0 14 15">
								<circle cx="2.5" cy="2.5" r="2.5"/>
								<circle cx="2.5" cy="12.5" r="2.5"/>
								<circle cx="11.5" cy="2.5" r="2.5"/>
								<circle cx="11.5" cy="12.5" r="2.5"/>
							</svg>
						}
					</div>
				</div>
				<div className="hidden xl:flex items-center gap-x-6">
					<a href="#" className="font-bold text-brand-black hover:text-blue-600">How it works</a>
					<a href="#" className="font-bold text-brand-black hover:text-blue-600">Pricing</a>
					<a href="#" className="font-bold text-brand-black hover:text-blue-600">Our Story</a>
					<div className='flex items-center gap-x-4'>
						<a href="#" className="btn btn-sm h-10 font-bold normal-case text-base bg-blue-600 text-white fill-white hover:text-blue-600 hover:fill-blue-600 hover:bg-transparent rounded-[104px] border !border-blue-600"><div className='w-5 h-5'><BiPerson /></div><p>Log in</p></a>
						<Link href="/signup" className="btn btn-sm h-10 font-bold normal-case text-base bg-indigo-100 text-blue-600 hover:text-white hover:bg-blue-600 border-none rounded-[114px]"><p>Schedule a Pickup</p></Link>
					</div>
				</div>
			</nav>
		</section>
		<div className='bg-black fixed h-screen w-screen z-40 px-8 transition-[bottom] duration-200' style={{ bottom: is_sidebar_open ? '0%' : '-100%' }} />
		<div className='bg-black fixed h-screen w-screen z-40 px-8 transition-[bottom] duration-500' style={{ bottom: is_sidebar_open ? '0%' : '-100%' }}>
			<div className='mt-[8.5rem] flex flex-col gap-y-1.5 [@media(min-height:400px)]:gap-y-4'>
				<a href="#" className="block [@media(min-height:400px)]:text-[2rem] font-bold text-white hover:text-blue-600">How it works</a>
				<a href="#" className="block [@media(min-height:400px)]:text-[2rem] font-bold text-white hover:text-blue-600">Pricing</a>
				<a href="#" className="block [@media(min-height:400px)]:text-[2rem] font-bold text-white hover:text-blue-600">Our Story</a>
				<a href="#" className="btn [@media(max-height:399px)]:btn-sm [@media(min-height:400px)]:mt-4 w-fit normal-case bg-blue-600 text-white fill-white hover:text-blue-600 hover:fill-blue-600 hover:bg-transparent rounded-full border !border-blue-600"><div className='w-5 h-5'><BiPerson /></div>Log in</a>
			</div>
		</div>
	</>
}
